# Install
```
pip install zeka
```

# Usage
Zeka is an opinionated cli tool for creating and mainting a zettelkasten note-taking system. 

The tool encourages a flat directory structure of markdown files with containing yaml frontmatter for metadata

# Examples
## Open quick note
```
zk
```

## Specifiy title
```
zk -t 'my-note'
```

## Add tags
```

